/*
 * gsampler-database-progress.c
 * Copyright (C) Lilian Monchalin 2011 <isaya07@users.sf.net>
 *
 * gsampler is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * gsampler is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "gsampler-database-progress.h"



G_DEFINE_TYPE (GsamplerDatabaseProgress, gsampler_database_progress, GTK_TYPE_VBOX);

static gboolean 
gsampler_database_progress_hide (gpointer data) 
{
	GsamplerDatabaseProgress* self;
	self = GSAMPLER_DATABASE_PROGRESS (data);
	g_return_val_if_fail (self != NULL, FALSE);

	gtk_progress_bar_set_text (self->progress, "");
	g_source_remove (self->timeout_id);
	gtk_widget_destroy ((GtkWidget*) self);
	return FALSE;
}

static void
gsampler_database_progress_init (GsamplerDatabaseProgress *self)
{
	self->title = (GtkLabel*) gtk_label_new ("Scanning Database");
	self->progress = (GtkProgressBar *) gtk_progress_bar_new ();
#if GTK_CHECK_VERSION (2, 90, 0)
	gtk_progress_bar_set_show_text (self->progress, TRUE);
#endif
	
	gtk_box_pack_start ((GtkBox*)self, (GtkWidget*) self->title, TRUE, FALSE, 5);
	gtk_box_pack_start ((GtkBox*)self, (GtkWidget*) self->progress, TRUE, FALSE, 5);
	gtk_widget_show_all ((GtkWidget*) self);
}

static void
gsampler_database_progress_finalize (GObject *object)
{
	/* TODO: Add deinitalization code here */

	G_OBJECT_CLASS (gsampler_database_progress_parent_class)->finalize (object);
}

static void
gsampler_database_progress_class_init (GsamplerDatabaseProgressClass *klass)
{
	GObjectClass* object_class = G_OBJECT_CLASS (klass);
	//GObjectClass* parent_class = G_OBJECT_CLASS (klass);

	object_class->finalize = gsampler_database_progress_finalize;
}

GsamplerDatabaseProgress *
gsampler_database_progress_new (void)
{
	return g_object_new (GSAMPLER_TYPE_DATABASE_PROGRESS, NULL);
}

void
gsampler_database_progress_update (GsamplerDatabaseProgress *self, gdouble fraction, const gchar *text)
{
	g_return_if_fail (self != NULL);

	if (((gint) fraction) == 1 && gtk_widget_get_visible ((GtkWidget*) self) != FALSE) 
	{
		self->timeout_id = g_timeout_add_full (G_PRIORITY_DEFAULT, (guint) 2000, 
		                                       gsampler_database_progress_hide, 
		                                       g_object_ref (self), g_object_unref);
	} else if (((gint) fraction) == 0 && gtk_widget_get_visible ((GtkWidget*) self) != TRUE) 
	{
		gtk_widget_show ((GtkWidget*) self);
	}
	gtk_progress_bar_set_fraction (self->progress, fraction);
	gtk_progress_bar_set_text (self->progress, text);

}